Class: Aws::ControlTower::Types::UpdateLandingZoneInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-controltower/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#landing_zone_identifierString

The unique identifier of the landing zone.

Returns:

  • (String)


2061
2062
2063
2064
2065
2066
2067
2068
# File 'lib/aws-sdk-controltower/types.rb', line 2061

class UpdateLandingZoneInput < Struct.new(
  :version,
  :remediation_types,
  :landing_zone_identifier,
  :manifest)
  SENSITIVE = []
  include Aws::Structure
end

#manifestHash, ...

The manifest file (JSON) is a text file that describes your Amazon Web Services resources. For an example, review Launch your landing zone. The example manifest file contains each of the available parameters. The schema for the landing zone's JSON manifest file is not published, by design.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


2061
2062
2063
2064
2065
2066
2067
2068
# File 'lib/aws-sdk-controltower/types.rb', line 2061

class UpdateLandingZoneInput < Struct.new(
  :version,
  :remediation_types,
  :landing_zone_identifier,
  :manifest)
  SENSITIVE = []
  include Aws::Structure
end

#remediation_typesArray<String>

Specifies the types of remediation actions to apply when updating the landing zone configuration.

Returns:

  • (Array<String>)


2061
2062
2063
2064
2065
2066
2067
2068
# File 'lib/aws-sdk-controltower/types.rb', line 2061

class UpdateLandingZoneInput < Struct.new(
  :version,
  :remediation_types,
  :landing_zone_identifier,
  :manifest)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The landing zone version, for example, 3.2.

Returns:

  • (String)


2061
2062
2063
2064
2065
2066
2067
2068
# File 'lib/aws-sdk-controltower/types.rb', line 2061

class UpdateLandingZoneInput < Struct.new(
  :version,
  :remediation_types,
  :landing_zone_identifier,
  :manifest)
  SENSITIVE = []
  include Aws::Structure
end