Class: Aws::ControlTower::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ControlTower::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-controltower/client.rb
Overview
An API client for ControlTower. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ControlTower::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_landing_zone(params = {}) ⇒ Types::CreateLandingZoneOutput
Creates a new landing zone.
-
#delete_landing_zone(params = {}) ⇒ Types::DeleteLandingZoneOutput
Decommissions a landing zone.
-
#disable_baseline(params = {}) ⇒ Types::DisableBaselineOutput
Disable an ‘EnabledBaseline` resource on the specified Target.
-
#disable_control(params = {}) ⇒ Types::DisableControlOutput
This API call turns off a control.
-
#enable_baseline(params = {}) ⇒ Types::EnableBaselineOutput
Enable (apply) a ‘Baseline` to a Target.
-
#enable_control(params = {}) ⇒ Types::EnableControlOutput
This API call activates a control.
-
#get_baseline(params = {}) ⇒ Types::GetBaselineOutput
Retrieve details about an existing ‘Baseline` resource by specifying its identifier.
-
#get_baseline_operation(params = {}) ⇒ Types::GetBaselineOperationOutput
Returns the details of an asynchronous baseline operation, as initiated by any of these APIs: ‘EnableBaseline`, `DisableBaseline`, `UpdateEnabledBaseline`, `ResetEnabledBaseline`.
-
#get_control_operation(params = {}) ⇒ Types::GetControlOperationOutput
Returns the status of a particular ‘EnableControl` or `DisableControl` operation.
-
#get_enabled_baseline(params = {}) ⇒ Types::GetEnabledBaselineOutput
Retrieve details of an ‘EnabledBaseline` resource by specifying its identifier.
-
#get_enabled_control(params = {}) ⇒ Types::GetEnabledControlOutput
Retrieves details about an enabled control.
-
#get_landing_zone(params = {}) ⇒ Types::GetLandingZoneOutput
Returns details about the landing zone.
-
#get_landing_zone_operation(params = {}) ⇒ Types::GetLandingZoneOperationOutput
Returns the status of the specified landing zone operation.
-
#list_baselines(params = {}) ⇒ Types::ListBaselinesOutput
Returns a summary list of all available baselines.
-
#list_control_operations(params = {}) ⇒ Types::ListControlOperationsOutput
Provides a list of operations in progress or queued.
-
#list_enabled_baselines(params = {}) ⇒ Types::ListEnabledBaselinesOutput
Returns a list of summaries describing ‘EnabledBaseline` resources.
-
#list_enabled_controls(params = {}) ⇒ Types::ListEnabledControlsOutput
Lists the controls enabled by Amazon Web Services Control Tower on the specified organizational unit and the accounts it contains.
-
#list_landing_zone_operations(params = {}) ⇒ Types::ListLandingZoneOperationsOutput
Lists all landing zone operations from the past 90 days.
-
#list_landing_zones(params = {}) ⇒ Types::ListLandingZonesOutput
Returns the landing zone ARN for the landing zone deployed in your managed account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns a list of tags associated with the resource.
-
#reset_enabled_baseline(params = {}) ⇒ Types::ResetEnabledBaselineOutput
Re-enables an ‘EnabledBaseline` resource.
-
#reset_enabled_control(params = {}) ⇒ Types::ResetEnabledControlOutput
Resets an enabled control.
-
#reset_landing_zone(params = {}) ⇒ Types::ResetLandingZoneOutput
This API call resets a landing zone.
-
#tag_resource(params = {}) ⇒ Struct
Applies tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_enabled_baseline(params = {}) ⇒ Types::UpdateEnabledBaselineOutput
Updates an ‘EnabledBaseline` resource’s applied parameters or version.
-
#update_enabled_control(params = {}) ⇒ Types::UpdateEnabledControlOutput
Updates the configuration of an already enabled control.
-
#update_landing_zone(params = {}) ⇒ Types::UpdateLandingZoneOutput
This API call updates the landing zone.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-controltower/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1813 1814 1815 |
# File 'lib/aws-sdk-controltower/client.rb', line 1813 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1816 1817 1818 |
# File 'lib/aws-sdk-controltower/client.rb', line 1816 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 |
# File 'lib/aws-sdk-controltower/client.rb', line 1786 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ControlTower') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-controltower' context[:gem_version] = '1.60.0' Seahorse::Client::Request.new(handlers, context) end |
#create_landing_zone(params = {}) ⇒ Types::CreateLandingZoneOutput
Creates a new landing zone. This API call starts an asynchronous operation that creates and configures a landing zone, based on the parameters specified in the manifest JSON file.
532 533 534 535 |
# File 'lib/aws-sdk-controltower/client.rb', line 532 def create_landing_zone(params = {}, = {}) req = build_request(:create_landing_zone, params) req.send_request() end |
#delete_landing_zone(params = {}) ⇒ Types::DeleteLandingZoneOutput
Decommissions a landing zone. This API call starts an asynchronous operation that deletes Amazon Web Services Control Tower resources deployed in accounts managed by Amazon Web Services Control Tower.
Decommissioning a landing zone is a process with significant consequences, and it cannot be undone. We strongly recommend that you perform this decommissioning process only if you intend to stop using your landing zone.
567 568 569 570 |
# File 'lib/aws-sdk-controltower/client.rb', line 567 def delete_landing_zone(params = {}, = {}) req = build_request(:delete_landing_zone, params) req.send_request() end |
#disable_baseline(params = {}) ⇒ Types::DisableBaselineOutput
Disable an ‘EnabledBaseline` resource on the specified Target. This API starts an asynchronous operation to remove all resources deployed as part of the baseline enablement. The resource will vary depending on the enabled baseline. For usage examples, see [ *the Amazon Web Services Control Tower User Guide* ][1].
[1]: docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html
604 605 606 607 |
# File 'lib/aws-sdk-controltower/client.rb', line 604 def disable_baseline(params = {}, = {}) req = build_request(:disable_baseline, params) req.send_request() end |
#disable_control(params = {}) ⇒ Types::DisableControlOutput
This API call turns off a control. It starts an asynchronous operation that deletes Amazon Web Services resources on the specified organizational unit and the accounts it contains. The resources will vary according to the control that you specify. For usage examples, see the [ *Controls Reference Guide* ][1].
[1]: docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html
661 662 663 664 |
# File 'lib/aws-sdk-controltower/client.rb', line 661 def disable_control(params = {}, = {}) req = build_request(:disable_control, params) req.send_request() end |
#enable_baseline(params = {}) ⇒ Types::EnableBaselineOutput
Enable (apply) a ‘Baseline` to a Target. This API starts an asynchronous operation to deploy resources specified by the `Baseline` to the specified Target. For usage examples, see [ *the Amazon Web Services Control Tower User Guide* ][1].
[1]: docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html
724 725 726 727 |
# File 'lib/aws-sdk-controltower/client.rb', line 724 def enable_baseline(params = {}, = {}) req = build_request(:enable_baseline, params) req.send_request() end |
#enable_control(params = {}) ⇒ Types::EnableControlOutput
This API call activates a control. It starts an asynchronous operation that creates Amazon Web Services resources on the specified organizational unit and the accounts it contains. The resources created will vary according to the control that you specify. For usage examples, see the [ *Controls Reference Guide* ][1].
[1]: docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html
795 796 797 798 |
# File 'lib/aws-sdk-controltower/client.rb', line 795 def enable_control(params = {}, = {}) req = build_request(:enable_control, params) req.send_request() end |
#get_baseline(params = {}) ⇒ Types::GetBaselineOutput
Retrieve details about an existing ‘Baseline` resource by specifying its identifier. For usage examples, see [ *the Amazon Web Services Control Tower User Guide* ][1].
[1]: docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html
833 834 835 836 |
# File 'lib/aws-sdk-controltower/client.rb', line 833 def get_baseline(params = {}, = {}) req = build_request(:get_baseline, params) req.send_request() end |
#get_baseline_operation(params = {}) ⇒ Types::GetBaselineOperationOutput
Returns the details of an asynchronous baseline operation, as initiated by any of these APIs: ‘EnableBaseline`, `DisableBaseline`, `UpdateEnabledBaseline`, `ResetEnabledBaseline`. A status message is displayed in case of operation failure. For usage examples, see [ *the Amazon Web Services Control Tower User Guide* ][1].
[1]: docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html
875 876 877 878 |
# File 'lib/aws-sdk-controltower/client.rb', line 875 def get_baseline_operation(params = {}, = {}) req = build_request(:get_baseline_operation, params) req.send_request() end |
#get_control_operation(params = {}) ⇒ Types::GetControlOperationOutput
Returns the status of a particular ‘EnableControl` or `DisableControl` operation. Displays a message in case of error. Details for an operation are available for 90 days. For usage examples, see the [ *Controls Reference Guide* ][1].
[1]: docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html
919 920 921 922 |
# File 'lib/aws-sdk-controltower/client.rb', line 919 def get_control_operation(params = {}, = {}) req = build_request(:get_control_operation, params) req.send_request() end |
#get_enabled_baseline(params = {}) ⇒ Types::GetEnabledBaselineOutput
Retrieve details of an ‘EnabledBaseline` resource by specifying its identifier.
958 959 960 961 |
# File 'lib/aws-sdk-controltower/client.rb', line 958 def get_enabled_baseline(params = {}, = {}) req = build_request(:get_enabled_baseline, params) req.send_request() end |
#get_enabled_control(params = {}) ⇒ Types::GetEnabledControlOutput
Retrieves details about an enabled control. For usage examples, see the [ *Controls Reference Guide* ][1].
[1]: docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html
1003 1004 1005 1006 |
# File 'lib/aws-sdk-controltower/client.rb', line 1003 def get_enabled_control(params = {}, = {}) req = build_request(:get_enabled_control, params) req.send_request() end |
#get_landing_zone(params = {}) ⇒ Types::GetLandingZoneOutput
Returns details about the landing zone. Displays a message in case of error.
1038 1039 1040 1041 |
# File 'lib/aws-sdk-controltower/client.rb', line 1038 def get_landing_zone(params = {}, = {}) req = build_request(:get_landing_zone, params) req.send_request() end |
#get_landing_zone_operation(params = {}) ⇒ Types::GetLandingZoneOperationOutput
Returns the status of the specified landing zone operation. Details for an operation are available for 90 days.
1072 1073 1074 1075 |
# File 'lib/aws-sdk-controltower/client.rb', line 1072 def get_landing_zone_operation(params = {}, = {}) req = build_request(:get_landing_zone_operation, params) req.send_request() end |
#list_baselines(params = {}) ⇒ Types::ListBaselinesOutput
Returns a summary list of all available baselines. For usage examples, see [ *the Amazon Web Services Control Tower User Guide* ][1].
[1]: docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1116 1117 1118 1119 |
# File 'lib/aws-sdk-controltower/client.rb', line 1116 def list_baselines(params = {}, = {}) req = build_request(:list_baselines, params) req.send_request() end |
#list_control_operations(params = {}) ⇒ Types::ListControlOperationsOutput
Provides a list of operations in progress or queued. For usage examples, see [ListControlOperation examples].
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1177 1178 1179 1180 |
# File 'lib/aws-sdk-controltower/client.rb', line 1177 def list_control_operations(params = {}, = {}) req = build_request(:list_control_operations, params) req.send_request() end |
#list_enabled_baselines(params = {}) ⇒ Types::ListEnabledBaselinesOutput
Returns a list of summaries describing ‘EnabledBaseline` resources. You can filter the list by the corresponding `Baseline` or `Target` of the `EnabledBaseline` resources. For usage examples, see [ *the Amazon Web Services Control Tower User Guide* ][1].
[1]: docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1245 1246 1247 1248 |
# File 'lib/aws-sdk-controltower/client.rb', line 1245 def list_enabled_baselines(params = {}, = {}) req = build_request(:list_enabled_baselines, params) req.send_request() end |
#list_enabled_controls(params = {}) ⇒ Types::ListEnabledControlsOutput
Lists the controls enabled by Amazon Web Services Control Tower on the specified organizational unit and the accounts it contains. For usage examples, see the [ *Controls Reference Guide* ][1].
[1]: docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1323 1324 1325 1326 |
# File 'lib/aws-sdk-controltower/client.rb', line 1323 def list_enabled_controls(params = {}, = {}) req = build_request(:list_enabled_controls, params) req.send_request() end |
#list_landing_zone_operations(params = {}) ⇒ Types::ListLandingZoneOperationsOutput
Lists all landing zone operations from the past 90 days. Results are sorted by time, with the most recent operation first.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1372 1373 1374 1375 |
# File 'lib/aws-sdk-controltower/client.rb', line 1372 def list_landing_zone_operations(params = {}, = {}) req = build_request(:list_landing_zone_operations, params) req.send_request() end |
#list_landing_zones(params = {}) ⇒ Types::ListLandingZonesOutput
Returns the landing zone ARN for the landing zone deployed in your managed account. This API also creates an ARN for existing accounts that do not yet have a landing zone ARN.
Returns one landing zone ARN.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1414 1415 1416 1417 |
# File 'lib/aws-sdk-controltower/client.rb', line 1414 def list_landing_zones(params = {}, = {}) req = build_request(:list_landing_zones, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns a list of tags associated with the resource. For usage examples, see the [ *Controls Reference Guide* ][1].
[1]: docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html
1448 1449 1450 1451 |
# File 'lib/aws-sdk-controltower/client.rb', line 1448 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#reset_enabled_baseline(params = {}) ⇒ Types::ResetEnabledBaselineOutput
Re-enables an ‘EnabledBaseline` resource. For example, this API can re-apply the existing `Baseline` after a new member account is moved to the target OU. For usage examples, see [ *the Amazon Web Services Control Tower User Guide* ][1].
[1]: docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html
1484 1485 1486 1487 |
# File 'lib/aws-sdk-controltower/client.rb', line 1484 def reset_enabled_baseline(params = {}, = {}) req = build_request(:reset_enabled_baseline, params) req.send_request() end |
#reset_enabled_control(params = {}) ⇒ Types::ResetEnabledControlOutput
Resets an enabled control. Does not work for controls implemented with SCPs.
1513 1514 1515 1516 |
# File 'lib/aws-sdk-controltower/client.rb', line 1513 def reset_enabled_control(params = {}, = {}) req = build_request(:reset_enabled_control, params) req.send_request() end |
#reset_landing_zone(params = {}) ⇒ Types::ResetLandingZoneOutput
This API call resets a landing zone. It starts an asynchronous operation that resets the landing zone to the parameters specified in the original configuration, which you specified in the manifest file. Nothing in the manifest file’s original landing zone configuration is changed during the reset process, by default. This API is not the same as a rollback of a landing zone version, which is not a supported operation.
1547 1548 1549 1550 |
# File 'lib/aws-sdk-controltower/client.rb', line 1547 def reset_landing_zone(params = {}, = {}) req = build_request(:reset_landing_zone, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Applies tags to a resource. For usage examples, see the [ *Controls Reference Guide* ][1].
[1]: docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html
1580 1581 1582 1583 |
# File 'lib/aws-sdk-controltower/client.rb', line 1580 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource. For usage examples, see the [ *Controls Reference Guide* ][1].
[1]: docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html
1611 1612 1613 1614 |
# File 'lib/aws-sdk-controltower/client.rb', line 1611 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_enabled_baseline(params = {}) ⇒ Types::UpdateEnabledBaselineOutput
Updates an ‘EnabledBaseline` resource’s applied parameters or version. For usage examples, see [ *the Amazon Web Services Control Tower User Guide* ][1].
[1]: docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html
1660 1661 1662 1663 |
# File 'lib/aws-sdk-controltower/client.rb', line 1660 def update_enabled_baseline(params = {}, = {}) req = build_request(:update_enabled_baseline, params) req.send_request() end |
#update_enabled_control(params = {}) ⇒ Types::UpdateEnabledControlOutput
Updates the configuration of an already enabled control.
If the enabled control shows an ‘EnablementStatus` of SUCCEEDED, supply parameters that are different from the currently configured parameters. Otherwise, Amazon Web Services Control Tower will not accept the request.
If the enabled control shows an ‘EnablementStatus` of FAILED, Amazon Web Services Control Tower updates the control to match any valid parameters that you supply.
If the ‘DriftSummary` status for the control shows as `DRIFTED`, you cannot call this API. Instead, you can update the control by calling the `ResetEnabledControl` API. Alternatively, you can call `DisableControl` and then call `EnableControl` again. Also, you can run an extending governance operation to repair drift. For usage examples, see the [ *Controls Reference Guide* ][1].
[1]: docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html
1719 1720 1721 1722 |
# File 'lib/aws-sdk-controltower/client.rb', line 1719 def update_enabled_control(params = {}, = {}) req = build_request(:update_enabled_control, params) req.send_request() end |
#update_landing_zone(params = {}) ⇒ Types::UpdateLandingZoneOutput
This API call updates the landing zone. It starts an asynchronous operation that updates the landing zone based on the new landing zone version, or on the changed parameters specified in the updated manifest file.
1777 1778 1779 1780 |
# File 'lib/aws-sdk-controltower/client.rb', line 1777 def update_landing_zone(params = {}, = {}) req = build_request(:update_landing_zone, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1806 1807 1808 |
# File 'lib/aws-sdk-controltower/client.rb', line 1806 def waiter_names [] end |