Class: Aws::ControlTower::Types::UpdateLandingZoneInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ControlTower::Types::UpdateLandingZoneInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-controltower/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#landing_zone_identifier ⇒ String
The unique identifier of the landing zone.
-
#manifest ⇒ Hash, ...
The manifest file (JSON) is a text file that describes your Amazon Web Services resources.
-
#remediation_types ⇒ Array<String>
Specifies the types of remediation actions to apply when updating the landing zone configuration.
-
#version ⇒ String
The landing zone version, for example, 3.2.
Instance Attribute Details
#landing_zone_identifier ⇒ String
The unique identifier of the landing zone.
2061 2062 2063 2064 2065 2066 2067 2068 |
# File 'lib/aws-sdk-controltower/types.rb', line 2061 class UpdateLandingZoneInput < Struct.new( :version, :remediation_types, :landing_zone_identifier, :manifest) SENSITIVE = [] include Aws::Structure end |
#manifest ⇒ Hash, ...
The manifest file (JSON) is a text file that describes your Amazon Web Services resources. For an example, review Launch your landing zone. The example manifest file contains each of the available parameters. The schema for the landing zone's JSON manifest file is not published, by design.
2061 2062 2063 2064 2065 2066 2067 2068 |
# File 'lib/aws-sdk-controltower/types.rb', line 2061 class UpdateLandingZoneInput < Struct.new( :version, :remediation_types, :landing_zone_identifier, :manifest) SENSITIVE = [] include Aws::Structure end |
#remediation_types ⇒ Array<String>
Specifies the types of remediation actions to apply when updating the landing zone configuration.
2061 2062 2063 2064 2065 2066 2067 2068 |
# File 'lib/aws-sdk-controltower/types.rb', line 2061 class UpdateLandingZoneInput < Struct.new( :version, :remediation_types, :landing_zone_identifier, :manifest) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The landing zone version, for example, 3.2.
2061 2062 2063 2064 2065 2066 2067 2068 |
# File 'lib/aws-sdk-controltower/types.rb', line 2061 class UpdateLandingZoneInput < Struct.new( :version, :remediation_types, :landing_zone_identifier, :manifest) SENSITIVE = [] include Aws::Structure end |